aboutsummaryrefslogtreecommitdiff
path: root/azalea-client/src/client.rs
diff options
context:
space:
mode:
authormat <git@matdoes.dev>2023-09-15 17:00:52 -0500
committermat <git@matdoes.dev>2023-09-15 17:00:52 -0500
commit659b6a1175298f4e2204c151e1fab0e18548f2ce (patch)
tree377bd6106584abad98ec011e7d1607a873e473ff /azalea-client/src/client.rs
parent622042fd41b89d2d9721314a9d136672bf00eac7 (diff)
downloadazalea-drasl-659b6a1175298f4e2204c151e1fab0e18548f2ce.tar.xz
rename start_ecs to start_ecs_runner
Diffstat (limited to 'azalea-client/src/client.rs')
-rw-r--r--azalea-client/src/client.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/azalea-client/src/client.rs b/azalea-client/src/client.rs
index 89e33dbc..f26fe6d8 100644
--- a/azalea-client/src/client.rs
+++ b/azalea-client/src/client.rs
@@ -230,7 +230,7 @@ impl Client {
let mut app = App::new();
app.add_plugins(DefaultPlugins);
- let ecs_lock = start_ecs(app, run_schedule_receiver, run_schedule_sender.clone());
+ let ecs_lock = start_ecs_runner(app, run_schedule_receiver, run_schedule_sender.clone());
Self::start_client(
ecs_lock,
@@ -243,7 +243,7 @@ impl Client {
}
/// Create a [`Client`] when you already have the ECS made with
/// [`start_ecs`]. You'd usually want to use [`Self::join`] instead.
pub async fn start_client(
ecs_lock: Arc<Mutex<World>>,
account: &Account,
@@ -634,7 +634,7 @@ impl Plugin for AzaleaPlugin {
/// You can create your app with `App::new()`, but don't forget to add
/// [`DefaultPlugins`].
#[doc(hidden)]
-pub fn start_ecs(
+pub fn start_ecs_runner(
app: App,
run_schedule_receiver: mpsc::UnboundedReceiver<()>,
run_schedule_sender: mpsc::UnboundedSender<()>,
@@ -243,7 +243,7 @@ impl Client {
}
/// Create a [`Client`] when you already have the ECS made with
- /// [`start_ecs`]. You'd usually want to use [`Self::join`] instead.
+ /// [`start_ecs_runner`]. You'd usually want to use [`Self::join`] instead.
pub async fn start_client(
ecs_lock: Arc<Mutex<World>>,